@@ -1,6 +1,5 @@
 import matplotlib
 import matplotlib.pyplot as plt
-from tmeasures.numpy.base import NumpyMeasure
 from .. import MeasureResult
 
 
@@ -18,7 +17,7 @@ def get_sequential_colors(values):
     colors = cmap(values)
     return colors
 
-from .layers import plot_average_activations_same_model,plot_average_activations_different_models,plot_average_activations
+from .layers import plot_average_activations_same_model,plot_average_activations_different_models,plot_average_activations,scatter_same_model
 from .heatmaps import plot_heatmap
 from .features import plot_invariant_feature_maps
 from .sample_size import plot_relative_error_heatmap,get_relative_errors
